#!/bin/sh

# Firefox launcher containing a Profile migration helper for
# temporary profiles used during alpha and beta phases.

# Original Authors:
#  Alexander Sack <asac@jwsdot.com>
#  Fabien Tassin <fta@sofaraway.org>
#  Steve Langasek <steve.langasek@canonical.com>

# Modified for Thunderbird by:
#  Micah Gersten <micahg@ubuntu.com>
# License: GPLv2 or later

# If there's a ~/.mozilla-thunderbird profile, copy to .thunderbird
# If nothing is found, we'll go for a fresh run and let thunderbird create a
# default profile for us.

HOMEDIR=$HOME
LIBDIR=/usr/lib/thunderbird-3.1.20
APPVER=
META_NAME=thunderbird
GDB=/usr/bin/gdb
DROPPED=abandoned

NAME=`which "$0"`
export MOZ_APP_LAUNCHER="$0"
if [ "x$META_NAME" != "x" ] ; then
  NAME="${NAME%%-$APPVER}"
fi
APPNAME="$(basename "$NAME")"

while [ ! -f "$LIBDIR/$APPNAME" ] && [ -L "$NAME" ]; do
  TARGET="$(readlink "$NAME")"
  if [ "x$TARGET" = "x$(basename "$TARGET")" ]; then
    TARGET="$(dirname "$NAME")/$TARGET"
  fi
  if [ "x$META_NAME" != "x" ] ; then
    TARGET=${TARGET%%-$APPVER}
  fi
  NAME="$TARGET"
  APPNAME="$(basename "$NAME")"
  if [ "x$APPNAME" = "xthunderbird.sh" ]; then
    APPNAME=thunderbird
    break
  fi
done

usage () {
  $LIBDIR/$APPNAME -h | sed -e 's,/.*/,,'
  echo
  echo "        -g or --debug		Start within $GDB (Must be first)"
}

want_debug=0
while [ $# -gt 0 ]; do
  case "$1" in
    -h | --help | -help )
      usage
      exit 0 ;;
    -g | --debug )
      want_debug=1
      shift ;;
    -- ) # Stop option prcessing
      shift
      break ;;
    * )
      break ;;
  esac
done

# If a Thunderbird 2 profile (.mozilla-thunderbird) is detected, if there is no # Thunderbird 3 profile (.thunderbird) move the Thunderbird 2 profile to
# .thunderbird
# if there is a Thunderbird 3 profile as well, run the migrator to ask the user
# which profile to use

FOUND_OLD=""
OLD_DIR=.mozilla-thunderbird
if [ -d $HOMEDIR/$OLD_DIR -a ! -h $HOMEDIR/$OLD_DIR ] ; then
  FOUND_OLD=$OLD_DIR;
fi

CURRENT=.thunderbird
FOUND_CURRENT=""
if [ -d $HOMEDIR/$CURRENT ] ; then
  FOUND_CURRENT=$CURRENT
fi

if [ "$FOUND_OLD" != "" ] ; then
  # Migrate only if $CURRENT isn't there (Only do this once)
  # If it exists, probably means that they already migrated
  if [ ! -d $HOMEDIR/$CURRENT ] ; then
    mv $HOMEDIR/$OLD_DIR $HOMEDIR/$CURRENT
  else
    echo -n "Found Multiple Thunderbird profiles ..."
    $LIBDIR/tb-beta-profile-migration-dialog
    result=$?
    if [ $result = 1 ]; then
      mv $HOMEDIR/$OLD_DIR $HOMEDIR/$CURRENT-2.0-replaced
      echo "Use Thunderbird 3 Profile."
    elif [ $result = 2 ]; then
      mv $HOMEDIR/$CURRENT $HOMEDIR/$CURRENT-3-replaced
      mv $HOMEDIR/$OLD_DIR $HOMEDIR/$CURRENT
      echo "Use Thunderbird 2 profile."
    else
      echo "Use Thunderbird 3 profile, but will ask again next time."
    fi
  fi
fi

if [ ! -h $HOMEDIR/$OLD_DIR -a ! -d $HOMEDIR/$OLD_DIR ] ; then
  ln -s $HOMEDIR/$CURRENT $HOMEDIR/$OLD_DIR
fi

if [ $want_debug -eq 1 ] ; then
  if [ ! -x $GDB ] ; then
    echo "Sorry, can't find usable $GDB. Please install it."
    exit 1
  fi
  tmpfile=`mktemp /tmp/mozargs.XXXXXX` || { echo "Cannot create temporary file" >&2; exit 1; }
  trap " [ -f \"$tmpfile\" ] && /bin/rm -f -- \"$tmpfile\"" 0 1 2 3 13 15
  echo "set args ${1+"$@"}" > $tmpfile
  echo "sh $LIBDIR/run-mozilla.sh $GDB "$LIBDIR/$META_NAME"-bin -x $tmpfile"
  # force command name to be thunderbird for run-mozilla.sh
  CMDNAME_USER=thunderbird sh $LIBDIR/run-mozilla.sh $GDB "$LIBDIR/$META_NAME"-bin -x $tmpfile
  exit $?
else
  # force command name to be thunderbird for run-mozilla.sh
  CMDNAME_USER=thunderbird exec $LIBDIR/$META_NAME "$@"
fi
